==> 0.11.1.tar.gz: lib/coupons_module/couponsPage.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:loyalty_management_tool/utils/colors.dart';
import 'package:loyalty_management_tool/utils/hexColors.dart';
import 'package:loyalty_management_tool/utils/localization.dart';

import '../bloc/common_widgets/customtabview.dart';
import '../bloc/cubits/cubit_main.dart';
import '../bloc/rewards_module/pages/ledger_history_page.dart';
import '../models/enums/payments_enums.dart';
import '../utils/customTabs.dart';
import '../utils/custom_app_bar.dart';
import '../utils/custom_tab_maker.dart';
import '../utils/customcard.dart';
import '../utils/text_styling.dart';
import 'CouponsListPage.dart';
import 'couponpageheadercard.dart';

class CouponsPage extends StatefulWidget {
  final bool isGift;

  CouponsPage({this.isGift = false});

  @override
  _CouponsPage createState() => _CouponsPage();
}

class _CouponsPage extends State<CouponsPage>
    with SingleTickerProviderStateMixin {
  List<CustomTabMaker> list = [];
  int _currentPosition = 0;
  TabController? _tabController;
  TextStyleElements? styleElements;
  String type = PaymentEnums.coins.type;
  GlobalKey<CouponPageHeaderCardState> couponPageHeaderKey = GlobalKey();
  GlobalKey<LeadgerHistoryPageState> ledgerKey = GlobalKey();

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((_) => loadPages());
  }

  onPositionChange() {
    if (!_tabController!.indexIsChanging && this.mounted) {
      setState(() {
        _currentPosition = _tabController!.index;
      });
    }
  }

  loadPages() {
/*    list.add(CustomTabMaker(
        statelessWidget: CouponsListPage(
          giftCardSelectCallback: null,
          isGift: widget.isGift,
          */ /*fetchData: () {
            couponPageHeaderKey.currentState!.fetchData();
          },*/ /*
        ),
        tabName: AppLocalizationsRewards.of(context)!.translate('coupons')));
    list.add(CustomTabMaker(
        statelessWidget: RedeemedCouponsListPage(isGift: widget.isGift),
        tabName: AppLocalizationsRewards.of(context)!.translate('my_coupons')));*/
    list.add(CustomTabMaker(
        statelessWidget: BlocProvider(
            create: (_) => CubitMain(),
            child: LeadgerHistoryPage(
              key: ledgerKey,
              type: type,
              refreshHistory: false,
            )),
        tabName: AppLocalizationsRewards.of(context)!.translate('history')));
    setState(() {
      _tabController = TabController(vsync: this, length: list.length);
      _tabController!.addListener(onPositionChange);
    });
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
        child: Scaffold(
            backgroundColor: HexColor(AppColors.greyBg),
            appBar: appAppBar().getCustomAppBar(context,
                appBarTitle: AppLocalizationsRewards.of(context)!
                    .translate('rewards'), onBackButtonPress: () {
              Navigator.pop(context);
            }),
            body: DefaultTabController(
                length: list.length,
                child: NestedScrollView(
                  headerSliverBuilder:
                      (BuildContext context, bool innerBoxIsScrolled) {
                    return [
                      SliverToBoxAdapter(
                        child: appCard(
                          padding: const EdgeInsets.all(0),
                          child: CouponPageHeaderCard(
                            changeCallBack: (value) {
                              print("refresh-------------");
                              if (value == 1) {
                                ledgerKey.currentState!
                                    .refresh(PaymentEnums.coins.type);
                              } else {
                                ledgerKey.currentState!
                                    .refresh(PaymentEnums.cash.type);
                              }
                            },
                            key: couponPageHeaderKey,
                          ),
                        ),
                      ),
                      // SliverToBoxAdapter(
                      //   child: Visibility(
                      //       visible: list.length > 0 ? true : false,
                      //       child: Container(
                      //         margin: const EdgeInsets.only(
                      //           left: 0,
                      //           right: 0,
                      //         ),
                      //         alignment: Alignment.center,
                      //         child: TabBar(
                      //           labelColor: HexColor(AppColors.appColorWhite),
                      //           indicatorColor: HexColor(AppColors.appColorTransparent),
                      //           controller: _tabController,
                      //           labelPadding: EdgeInsets.symmetric(horizontal: 2.0),
                      //           isScrollable: true,
                      //           tabs: List<Widget>.generate(list.length, (int index) {
                      //             return new Tab(
                      //               child: appTabButton(
                      //                 onPressed: () {
                      //                   _tabController!.animateTo(index);
                      //                   if (this.mounted) {
                      //                     setState(() {
                      //                       _currentPosition = index;
                      //                     });
                      //                   }
                      //                 },
                      //                 isActive: index == _currentPosition,
                      //                 tabName: list[index].tabName,
                      //               ),
                      //             );
                      //           }),
                      //         ),
                      //       ),
                      //   ),
                      // ),
                    ];
                  },
                  body: CustomTabView(
                    isTabVisible: true,
                    isSwipeDisabled: false,
                    marginTop: const EdgeInsets.all(16.0),
                    currentPosition: _currentPosition,
                    itemCount: list.isNotEmpty ? list.length : 0,
                    tabBuilder: (context, index) => appTabButton(
                      onPressed: () {
                        setState(() {
                          _currentPosition = index;
                        });
                      },
                      tabName: list[index].tabName,
                      isActive: index == _currentPosition,
                    ),
                    pageBuilder: (context, index) =>
                        Center(child: list[index].statelessWidget),
                    onPositionChange: (index) {
                      setState(() {
                        _currentPosition = index!;
                      });
                    },
                    onScroll: (position) => print('$position'),
                  ),
                ))));
  }
}

==> 0.22.14.tar.gz: lib/coupons_module/couponsPage.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:loyalty_management_tool/utils/colors.dart';
import 'package:loyalty_management_tool/utils/hexColors.dart';
import 'package:loyalty_management_tool/utils/localization.dart';

import '../bloc/common_widgets/customtabview.dart';
import '../bloc/cubits/cubit_main.dart';
import '../bloc/rewards_module/pages/ledger_history_page.dart';
import '../models/enums/payments_enums.dart';
import '../utils/customTabs.dart';
import '../utils/custom_app_bar.dart';
import '../utils/custom_tab_maker.dart';
import '../utils/customcard.dart';
import '../utils/text_styling.dart';
import 'couponpageheadercard.dart';

class CouponsPage extends StatefulWidget {
  final bool isGift;

  CouponsPage({this.isGift = false});

  @override
  _CouponsPage createState() => _CouponsPage();
}

class _CouponsPage extends State<CouponsPage>
    with SingleTickerProviderStateMixin {
  List<CustomTabMaker> list = [];
  int _currentPosition = 0;
  TabController? _tabController;
  TextStyleElements? styleElements;
  String type = PaymentEnums.coins.type;
  GlobalKey<CouponPageHeaderCardState> couponPageHeaderKey = GlobalKey();
  GlobalKey<LeadgerHistoryPageState> ledgerKey = GlobalKey();

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addPostFrameCallback((_) => loadPages());
  }

  onPositionChange() {
    if (!_tabController!.indexIsChanging && this.mounted) {
      setState(() {
        _currentPosition = _tabController!.index;
      });
    }
  }

  loadPages() {
/*    list.add(CustomTabMaker(
        statelessWidget: CouponsListPage(
          giftCardSelectCallback: null,
          isGift: widget.isGift,
          */ /*fetchData: () {
            couponPageHeaderKey.currentState!.fetchData();
          },*/ /*
        ),
        tabName: AppLocalizationsRewards.of(context)!.translate('coupons')));
    list.add(CustomTabMaker(
        statelessWidget: RedeemedCouponsListPage(isGift: widget.isGift),
        tabName: AppLocalizationsRewards.of(context)!.translate('my_coupons')));*/
    list.add(CustomTabMaker(
        statelessWidget: BlocProvider(
            create: (_) => CubitMain(),
            child: LeadgerHistoryPage(
              key: ledgerKey,
              type: type,
              refreshHistory: false,
            )),
        tabName: AppLocalizationsRewards.of(context)!.translate('history')));
    setState(() {
      _tabController = TabController(vsync: this, length: list.length);
      _tabController!.addListener(onPositionChange);
    });
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
        child: Scaffold(
            backgroundColor: HexColor(AppColors.greyBg),
            appBar: appAppBar().getCustomAppBar(context,
                appBarTitle: AppLocalizationsRewards.of(context)!
                    .translate('rewards'), onBackButtonPress: () {
              Navigator.pop(context);
            }),
            body: DefaultTabController(
                length: list.length,
                child: NestedScrollView(
                  headerSliverBuilder:
                      (BuildContext context, bool innerBoxIsScrolled) {
                    return [
                      SliverToBoxAdapter(
                        child: appCard(
                          padding: const EdgeInsets.all(0),
                          child: CouponPageHeaderCard(
                            changeCallBack: (value) {
                              print("refresh-------------");
                              if (value == 1) {
                                ledgerKey.currentState!
                                    .refresh(PaymentEnums.coins.type);
                              } else {
                                ledgerKey.currentState!
                                    .refresh(PaymentEnums.cash.type);
                              }
                            },
                            key: couponPageHeaderKey,
                          ),
                        ),
                      ),
                      // SliverToBoxAdapter(
                      //   child: Visibility(
                      //       visible: list.length > 0 ? true : false,
                      //       child: Container(
                      //         margin: const EdgeInsets.only(
                      //           left: 0,
                      //           right: 0,
                      //         ),
                      //         alignment: Alignment.center,
                      //         child: TabBar(
                      //           labelColor: HexColor(AppColors.appColorWhite),
                      //           indicatorColor: HexColor(AppColors.appColorTransparent),
                      //           controller: _tabController,
                      //           labelPadding: EdgeInsets.symmetric(horizontal: 2.0),
                      //           isScrollable: true,
                      //           tabs: List<Widget>.generate(list.length, (int index) {
                      //             return new Tab(
                      //               child: appTabButton(
                      //                 onPressed: () {
                      //                   _tabController!.animateTo(index);
                      //                   if (this.mounted) {
                      //                     setState(() {
                      //                       _currentPosition = index;
                      //                     });
                      //                   }
                      //                 },
                      //                 isActive: index == _currentPosition,
                      //                 tabName: list[index].tabName,
                      //               ),
                      //             );
                      //           }),
                      //         ),
                      //       ),
                      //   ),
                      // ),
                    ];
                  },
                  body: CustomTabView(
                    isTabVisible: true,
                    isSwipeDisabled: false,
                    marginTop: const EdgeInsets.all(16.0),
                    currentPosition: _currentPosition,
                    itemCount: list.isNotEmpty ? list.length : 0,
                    tabBuilder: (context, index) => appTabButton(
                      onPressed: () {
                        setState(() {
                          _currentPosition = index;
                        });
                      },
                      tabName: list[index].tabName,
                      isActive: index == _currentPosition,
                    ),
                    pageBuilder: (context, index) =>
                        Center(child: list[index].statelessWidget),
                    onPositionChange: (index) {
                      setState(() {
                        _currentPosition = index!;
                      });
                    },
                    onScroll: (position) => print('$position'),
                  ),
                ))));
  }
}
